/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.bescheid;

import java.util.Objects;

import jakarta.annotation.PostConstruct;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import de.ozgcloud.bescheid.vorgang.VorgangService;
import de.ozgcloud.common.errorhandling.TechnicalException;
import lombok.extern.log4j.Log4j2;

@Service
@Log4j2
class BescheidService {

	private static final String ERROR_MESSAGE_NO_SERVICE = "'CREATE_BESCHEID' Command received but no Bescheid Endpoint is configured.";

	@Autowired
	private VorgangService vorgangService;
	@Autowired(required = false)
	private BescheidRemoteService remoteService;

	@PostConstruct
	void logStatus() {
		if (Objects.isNull(ERROR_MESSAGE_NO_SERVICE)) {
			LOG.info("No BescheidRemoteService configured - Bescheid creation is not possible.");
		} else {
			LOG.info("Bescheid-Manager is configured.");
		}
	}

	public Bescheid createBescheid(BescheidRequest request) {
		checkRemoteService();

		return doCreateBescheid(request);
	}

	private Bescheid doCreateBescheid(BescheidRequest request) {
		var vorgang = vorgangService.getById(request.getVorgangId());
		return remoteService.create(request, vorgang)
				.toBuilder().vorgangId(vorgang.getId()).serviceKonto(vorgang.getServiceKonto())
				.build();
	}

	private void checkRemoteService() {
		if (Objects.isNull(remoteService)) {
			LOG.error(ERROR_MESSAGE_NO_SERVICE);
			throw new TechnicalException(ERROR_MESSAGE_NO_SERVICE);
		}
	}

}
