/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.bescheid.nachricht;

import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.bescheid.UserId;
import de.ozgcloud.bescheid.vorgang.Vorgang;
import de.ozgcloud.common.binaryfile.FileId;
import de.ozgcloud.nachrichten.postfach.GrpcPostfachNachricht;
import de.ozgcloud.vorgang.common.grpc.GrpcObjectMapper;
import de.ozgcloud.vorgang.vorgang.GrpcPostfachAddress;

@Mapper(collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED, //
		nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS, unmappedTargetPolicy = ReportingPolicy.ERROR, uses = { GrpcObjectMapper.class })
public interface NachrichtMapper {

	@Mapping(target = "createdAtBytes", ignore = true)
	@Mapping(target = "mergePostfachAddress", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "idBytes", ignore = true)
	@Mapping(target = "mailBodyBytes", ignore = true)
	@Mapping(target = "replyOptionBytes", ignore = true)
	@Mapping(target = "subjectBytes", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "allFields", ignore = true)

	@Mapping(target = "id", ignore = true)
	@Mapping(target = "attachmentList", source = "bescheidFileId")
	@Mapping(target = "replyOption", constant = "FORBIDDEN")
	GrpcPostfachNachricht mapToGrpc(Nachricht nachricht);

	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "mergeIdentifier", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "versionBytes", ignore = true)
	@Mapping(target = "allFields", ignore = true)
	GrpcPostfachAddress mapAddress(Vorgang.PostfachAddress address);

	default String mapToString(FileId fileId) {
		return fileId.toString();
	}

	default String mapToString(UserId userId) {
		return userId.toString();
	}
}
