/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.bescheid.nachricht;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import de.ozgcloud.nachrichten.postfach.GrpcSaveNachrichtDraftRequest;
import de.ozgcloud.nachrichten.postfach.PostfachServiceGrpc.PostfachServiceBlockingStub;
import io.grpc.ClientInterceptor;
import net.devh.boot.grpc.client.inject.GrpcClient;

@Service
class NachrichtRemoteService {

	@GrpcClient("nachrichten-manager")
	private PostfachServiceBlockingStub serviceStub;

	@Autowired
	private NachrichtMapper mapper;

	@Autowired
	private ClientInterceptor bescheidCallContextInterceptor;

	public void saveDraft(Nachricht nachricht) {
		serviceStub.withInterceptors(bescheidCallContextInterceptor)
				.saveNachrichtDraft(buildRequest(nachricht));
	}

	GrpcSaveNachrichtDraftRequest buildRequest(Nachricht nachricht) {
		return GrpcSaveNachrichtDraftRequest.newBuilder()
				.setVorgangId(nachricht.getVorgangId().toString())
				.setNachricht(mapper.mapToGrpc(nachricht))
				.build();
	}
}
