/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.bescheid.smartdocuments;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.client.reactive.ReactorClientHttpConnector;
import org.springframework.web.reactive.function.client.ExchangeFilterFunctions;
import org.springframework.web.reactive.function.client.WebClient;

import reactor.netty.http.client.HttpClient;
import reactor.netty.transport.ProxyProvider;

@Configuration
@ConditionalOnProperty("ozgcloud.bescheid.smart-documents.url")
class SmartDocumentsConfiguration {

	@Autowired
	private SmartDocumentsProperties properties;

	@Bean("smartDocuments")
	WebClient smartDocumentsWebClient() {
		ReactorClientHttpConnector connector = new ReactorClientHttpConnector(buildHttpClient());

		return WebClient.builder()
				.baseUrl(properties.getUrl())
				.filter(ExchangeFilterFunctions.basicAuthentication(properties.getBasicAuth().getUsername(), properties.getBasicAuth().getPassword()))
				.clientConnector(connector)
				.build();
	}

	private HttpClient buildHttpClient() {
		if (properties.getProxy() != null) {
			return createProxyHttpClient();
		} else {
			return createNoProxyHttpClient();
		}
	}

	private HttpClient createNoProxyHttpClient() {
		return HttpClient.create();
	}

	private HttpClient createProxyHttpClient() {
		return HttpClient.create()
				.proxy(proxy -> proxy.type(ProxyProvider.Proxy.HTTP)
						.host(properties.getProxy().getHost())
						.port(properties.getProxy().getPort())
						.username(properties.getProxy().getUsername())
						.password(username -> properties.getProxy().getPassword()));
	}

}
