/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.bescheid.smartdocuments;

import java.time.LocalDate;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.PropertyNamingStrategies;
import com.fasterxml.jackson.databind.annotation.JsonNaming;

import de.ozgcloud.bescheid.vorgang.Vorgang;
import lombok.Builder;
import lombok.Getter;
import lombok.ToString;

@Builder
@Getter
@JsonNaming(PropertyNamingStrategies.UpperCamelCaseStrategy.class)
@ToString
class SmartDocumentsRequest {

	@Builder.Default
	private CustomerData customerData = CustomerData.builder().build();
	@Builder.Default
	private SmartDocument smartDocument = SmartDocument.builder().build();

	@Builder
	@Getter
	static class CustomerData {
		private Vorgang vorgang;
		private BescheidData bescheid;
		private UserData userData;

		@Builder
		@Getter
		static class BescheidData {
			private LocalDate bescheidVom;
			private boolean genehmigt;
		}

		@Builder
		@Getter
		static class UserData {
			private String firstName;
			private String lastName;
			private String email;
		}
	}

	@Builder
	@Getter
	@JsonNaming(PropertyNamingStrategies.UpperCamelCaseStrategy.class)
	static class SmartDocument {

		@Builder.Default
		@JsonProperty("Selection")
		private Selection selection = Selection.builder().build();

		@Builder
		@Getter
		@JsonNaming(PropertyNamingStrategies.UpperCamelCaseStrategy.class)
		static class Selection {
			@Builder.Default
			private String templateGroup = "Kiel";
			@Builder.Default
			private String template = "Halteverbot";
		}
	}

}
