/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.bescheid.vorgang;

import java.util.List;
import java.util.stream.Stream;

import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.Named;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.bescheid.vorgang.FormDataEntry.FormField;
import de.ozgcloud.bescheid.vorgang.FormDataEntry.SubForm;
import de.ozgcloud.vorgang.vorgang.GrpcFormField;
import de.ozgcloud.vorgang.vorgang.GrpcSubForm;

@Mapper(unmappedTargetPolicy = ReportingPolicy.ERROR)
public interface FormDataEntryMapper {

	@Mapping(target = "entries", source = ".", qualifiedByName = "mapEntrys")
	@Mapping(target = "entry", ignore = true)
	@Mapping(target = "name", source = "title")
	SubForm fromGrpc(GrpcSubForm subForm);

	FormField fromGrpc(GrpcFormField field);

	@Named("mapEntrys")
	default List<FormDataEntry> mapEntrys(GrpcSubForm subForm) {
		var fieldStream = subForm.getFieldList().stream().map(this::fromGrpc);
		var subFormsStream = subForm.getSubFormList().stream().map(this::fromGrpc);

		return Stream.concat(fieldStream, subFormsStream).toList();
	}

}
