/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.bescheid;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import io.grpc.stub.StreamObserver;

class BescheidGrpcServiceTest {

	@Spy
	@InjectMocks
	private BescheidGrpcService service;

	@Mock
	private GrpcBescheidMapper mapper;

	@BeforeEach
	void initMapperMock() {
		when(mapper.fromBescheid(any())).thenReturn(GrpcBescheidTestFactory.create());
	}

	@Nested
	class TestGetBescheidDraft {

		@Mock
		private GrpcGetBescheidDraftRequest request;
		@Mock
		private StreamObserver<GrpcGetBescheidDraftResponse> responseObserver;

		private static final GrpcGetBescheidDraftResponse response = GrpcGetBescheidDraftResponse.newBuilder().build();

		@BeforeEach
		void initMocks() {
			when(service.buildResponse(any())).thenReturn(response);
		}

		@Test
		void shouldBuildResponse() {
			service.getBescheidDraft(request, responseObserver);

			verify(service).buildResponse(any());
		}

		@Test
		void shouldCallNext() {
			service.getBescheidDraft(request, responseObserver);

			verify(responseObserver).onNext(response);
		}

		@Test
		void shouldCallCompleted() {
			service.getBescheidDraft(request, responseObserver);

			verify(responseObserver).onCompleted();
		}

	}

	@Nested
	class TestBuildResponse {

		@Test
		void shouldCallMapper() {
			Bescheid bescheid = BescheidTestFactory.create();

			service.buildResponse(bescheid);

			verify(mapper).fromBescheid(bescheid);
		}
	}

}
