/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.bescheid;

import java.io.File;
import java.util.Optional;

import org.springframework.http.MediaType;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.bescheid.common.callcontext.UserProfileTestFactory;
import de.ozgcloud.bescheid.vorgang.ServiceKontoTestFactory;
import de.ozgcloud.bescheid.vorgang.VorgangTestFactory;
import de.ozgcloud.common.binaryfile.TempFileUtils;

public class BescheidTestFactory {

	public static final UserId CREATED_BY = UserProfileTestFactory.ID;
	public static final String FILE_NAME = "bescheid.pdf";

	public static final byte[] TEST_BESCHEID = "testbescheid".getBytes();
	public static final File BESCHEID_FILE = TempFileUtils.writeTmpFile(TEST_BESCHEID);

	public static final String CONTENT_TYPE = MediaType.APPLICATION_PDF_VALUE;
	public static final String NACHRICHT_TEXT = LoremIpsum.getInstance().getWords(5);

	public static Bescheid create() {
		return createBuilder().build();
	}

	public static Bescheid.BescheidBuilder createBuilder() {
		return Bescheid.builder()
				.createdBy(CREATED_BY)
				.vorgangId(VorgangTestFactory.ID)
				.contentType(CONTENT_TYPE)
				.bescheidFileName(FILE_NAME)
				.bescheidFile(BESCHEID_FILE)
				.nachrichtText(Optional.of(NACHRICHT_TEXT))
				.genehmigt(true)
				.size(TEST_BESCHEID.length)
				.serviceKonto(ServiceKontoTestFactory.create());
	}
}
