/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.bescheid.nachricht;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;

class NachrichtMapperTest {

	@InjectMocks
	private NachrichtMapper mapper = Mappers.getMapper(NachrichtMapper.class);;

	@Nested
	class TestMapToGrpc {
		@Test
		void shouldMapNachricht() {
			var mapped = mapper.mapToGrpc(NachrichtTestFactory.create());

			assertThat(mapped).usingRecursiveComparison()
					.ignoringFields("replyOption_", "memoizedHashCode")
					.isEqualTo(GrpcPostfachNachrichtTestFactory.create());
		}

		@Test
		void shouldIgnoreMissingFileId() {
			var mapped = mapper.mapToGrpc(NachrichtTestFactory.createBuilder().bescheidFileId(null).build());

			assertThat(mapped.getAttachmentList()).isEmpty();
		}

		@Test
		void shouldSetReplyOption() {
			var mapped = mapper.mapToGrpc(NachrichtTestFactory.create());

			assertThat(mapped.getReplyOption()).isEqualTo("FORBIDDEN");
		}

		@Test
		void shouldNotMapId() {
			var mapped = mapper.mapToGrpc(NachrichtTestFactory.create());

			assertThat(mapped.getId()).isEmpty();
		}
	}

}
