/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.bescheid.nachricht;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.bescheid.vorgang.VorgangTestFactory;
import de.ozgcloud.nachrichten.postfach.GrpcPostfachNachricht;

class NachrichtRemoteServiceTest {

	@InjectMocks
	private NachrichtRemoteService remoteService;

	@Mock
	private NachrichtMapper mapper;

	@Nested
	class TestSaveDarft {
		@Nested
		class BuildRequest {
			private Nachricht nachricht = NachrichtTestFactory.create();
			private GrpcPostfachNachricht grpcNachricht = GrpcPostfachNachrichtTestFactory.create();

			@BeforeEach
			void initMocks() {
				when(mapper.mapToGrpc(any())).thenReturn(grpcNachricht);
			}

			@Test
			void shouldCallMapper() {
				remoteService.buildRequest(nachricht);

				verify(mapper).mapToGrpc(nachricht);
			}

			@Test
			void shouldSetNachricht() {
				var request = remoteService.buildRequest(nachricht);

				assertThat(request.getNachricht()).isSameAs(grpcNachricht);
			}

			@Test
			void shouldSetVorgangId() {
				var request = remoteService.buildRequest(nachricht);

				assertThat(request.getVorgangId()).isEqualTo(VorgangTestFactory.ID.toString());
			}
		}
	}

}
