/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.bescheid.nachricht;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;

import de.ozgcloud.common.test.ITCase;
import de.ozgcloud.bescheid.BescheidTestFactory;

@ITCase
class NachrichtServiceITCase {

	@Autowired
	private NachrichtService service;

	@Nested
	class TestBuildMessage {
		@Test
		void shouldBuildMessage() {
			var message = service.buildMessage(BescheidTestFactory.create());

			assertThat(message).isNotBlank();
		}

		@Test
		void shouldBeGenehmigt() {
			var message = service.buildMessage(BescheidTestFactory.createBuilder().genehmigt(true).build());

			assertThat(message).contains("genehmigt").doesNotContain("abgelehnt");
		}

		@Test
		void shouldBeAbgelehnt() {
			var message = service.buildMessage(BescheidTestFactory.createBuilder().genehmigt(false).build());

			assertThat(message).contains("abgelehnt").doesNotContain("genehmigt");
		}
	}

}
