/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.bescheid.nachricht;

import java.time.ZonedDateTime;
import java.util.UUID;

import de.ozgcloud.bescheid.UserId;
import de.ozgcloud.bescheid.vorgang.VorgangTestFactory;

public class NachrichtTestFactory {

	public static final NachrichtId ID = NachrichtId.from(UUID.randomUUID().toString());

	public static final String SUBJECT = "subject of message";
	public static final String MAIL_BODY = "Lorem ipsum";

	public static final UserId CREATED_BY = UserId.from(UUID.randomUUID().toString());
	public static final ZonedDateTime CREATED_AT = ZonedDateTime.now().withNano(0);

	public static Nachricht create() {
		return createBuilder().build();
	}

	public static Nachricht.NachrichtBuilder createBuilder() {
		return Nachricht.builder()
				.id(ID)
				.vorgangId(VorgangTestFactory.ID)
				.subject(SUBJECT)
				.mailBody(MAIL_BODY)
				.createdBy(CREATED_BY)
				.createdAt(CREATED_AT);
	}
}
