/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.bescheid.vorgang;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Test;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;

import de.ozgcloud.bescheid.vorgang.FormDataEntry.FormField;
import de.ozgcloud.bescheid.vorgang.FormDataEntry.SubForm;
import de.ozgcloud.bescheid.vorgang.Vorgang.Eingang;
import lombok.SneakyThrows;

class FormDataEntrySerializerTest {

	private ObjectMapper mapper = new ObjectMapper();

	@Test
	void schouldSerializeFormDataWithSingleField() throws JsonProcessingException {
		var eingang = Eingang.builder()
				.formData(FormField.builder().name("name").value("Thea").build())
				.build();

		var json = mapper.writeValueAsString(eingang);

		assertThat(json).contains("\"formData\":{\"name\":\"Thea\"}");
	}

	@Test
	@SneakyThrows
	void sohludSerializeFormDataWithSubForm() {
		var eingang = Eingang.builder()
				.formData(SubForm.builder().name("address")
						.entry(FormField.builder().name("name").value("Thea").build())
						.build())
				.build();

		var json = mapper.writeValueAsString(eingang);

		assertThat(json).contains("\"formData\":{\"address\":{\"name\":\"Thea\"}}");
	}

	@Test
	@SneakyThrows
	void shouldSerializeFormDataWithSubSubForm() {
		var eingang = Eingang.builder()
				.formData(SubForm.builder().name("address")
						.entry(SubForm.builder().name("person")
								.entry(FormField.builder().name("name").value("Thea").build())
								.build())
						.build())
				.build();

		var json = mapper.writeValueAsString(eingang);

		assertThat(json).contains("\"formData\":{\"address\":{\"person\":{\"name\":\"Thea\"}}}");
	}

	@Test
	@SneakyThrows
	void shouldSerializeFormWithTwoFields() {
		var eingang = Eingang.builder()
				.formData(FormField.builder().name("firstname").value("Thea").build())
				.formData(FormField.builder().name("lastname").value("Test").build())
				.build();

		var json = mapper.writeValueAsString(eingang);

		assertThat(json).contains("\"formData\":{\"firstname\":\"Thea\",\"lastname\":\"Test\"}");
	}
}
