/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.bayernid;

import java.io.InputStream;
import java.util.Optional;

import org.bson.Document;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.stereotype.Service;

import com.mongodb.client.gridfs.model.GridFSFile;

import de.ozgcloud.common.errorhandling.TechnicalException;
import de.ozgcloud.nachrichten.postfach.BinaryFileService;
import de.ozgcloud.nachrichten.postfach.FileId;

@Service
@ConditionalOnProperty(prefix = "ozgcloud.bayernid", name = { "enabled" })
public class BayernIdAttachmentService {

	static final String NAME_KEY = "name";
	static final String CONTENT_TYPE_KEY = "contentType";

	@Autowired
	private BinaryFileService binaryFileService;

	public BayernIdAttachment getMessageAttachment(FileId fileId) {
		return Optional.ofNullable(binaryFileService.getFile(fileId))
				.map(GridFSFile::getMetadata)
				.map(metadata -> buildBayernIdAttachment(metadata, getAttachmentContentStream(fileId)))
				.orElseThrow(() -> new TechnicalException("Can not find attachment with id " + fileId));
	}

	BayernIdAttachment buildBayernIdAttachment(Document metadata, InputStream attachmentContent) {
		return BayernIdAttachment.builder()
				.fileName(metadata.getString(NAME_KEY))
				.contentType(metadata.getString(CONTENT_TYPE_KEY))
				.content(attachmentContent)
				.build();
	}

	InputStream getAttachmentContentStream(FileId fileId) {
		return binaryFileService.getUploadedFileStream(fileId);
	}
}
