/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.bayernid;

import de.ozgcloud.nachrichten.postfach.PostfachException;
import de.ozgcloud.nachrichten.postfach.PostfachMessageCode;

class BayernIdServerException extends PostfachException {

	static final String TABELLE_NUMMER_EMPFANG_ERGEBNISSTATUS = "9006";
	private static final String ERROR_MESSAGE_TEMPLATE = TABELLE_NUMMER_EMPFANG_ERGEBNISSTATUS + " / %s / %s / %s";

	private final MailSendingResponseStatus mailSendingResponseStatus;

	public BayernIdServerException(String message) {
		super(message, PostfachMessageCode.PROCESS_FAILED_MESSAGE_CODE);
		this.mailSendingResponseStatus = null;
	}

	public BayernIdServerException(String message, MailSendingResponseStatus mailSendingResponseStatus) {
		super(message, PostfachMessageCode.PROCESS_FAILED_MESSAGE_CODE);
		this.mailSendingResponseStatus = mailSendingResponseStatus;
	}

	@Override
	public String getMessage() {
		if (mailSendingResponseStatus == null) {
			return super.getMessage();
		}
		return ERROR_MESSAGE_TEMPLATE.formatted(mailSendingResponseStatus.getSchluessel(), mailSendingResponseStatus.getMessage(), super.getMessage());
	}
}
