/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.notification.command;

import java.util.Optional;

import org.mapstruct.Mapper;
import org.mapstruct.Mapping;

import de.ozgcloud.notification.vorgang.VorgangId;
import de.ozgcloud.vorgang.common.grpc.GrpcObjectMapper;
import de.ozgcloud.vorgang.grpc.command.GrpcCreateCommandRequest;

@Mapper(uses = GrpcObjectMapper.class)
interface CommandMapper {

	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "mergeBodyObj", ignore = true)
	@Mapping(target = "mergeCallContext", ignore = true)
	@Mapping(target = "mergeRedirectRequest", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "removeBody", ignore = true)
	@Mapping(target = "callContext", ignore = true)
	@Mapping(target = "orderStringBytes", ignore = true)
	@Mapping(target = "order", ignore = true)
	@Mapping(target = "orderValue", ignore = true)
	@Mapping(target = "redirectRequest", ignore = true)
	@Mapping(target = "relationIdBytes", ignore = true)
	@Mapping(target = "relationVersion", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "vorgangIdBytes", ignore = true)
	@Mapping(target = "allFields", ignore = true)
	@Mapping(target = "bodyBuilderList", ignore = true)
	@Mapping(target = "bodyList", ignore = true)
	@Mapping(target = "bodyOrBuilderList", ignore = true)

	@Mapping(target = "bodyObj", source = "body")
	@Mapping(target = "orderString", source = "order")
	GrpcCreateCommandRequest toGrpcRequest(Command command);

	default String toString(VorgangId vorgangId) {
		return Optional.ofNullable(vorgangId)
				.map(VorgangId::toString)
				.orElse(null);
	}
}
