/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.notification.user;

import static java.util.Objects.*;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import de.ozgcloud.notification.email.EmailRemoteService;
import de.ozgcloud.notification.email.UserEmail;
import de.ozgcloud.notification.vorgang.Vorgang;
import lombok.NonNull;

@Service
public class UserNotificationService {

	public static final String MAIL_SUBJECT_TEMPLATE = "Neuer Vorgang: %s";
	public static final String MAIL_BODY = "Es ist ein neuer Vorgang im Allgemeinen Fachverfahren eingegangen.";

	@Autowired
	private EmailRemoteService emailRemoteService;

	@Autowired
	private UserRemoteService userRemoteService;

	@Async
	public void sendNotification(@NonNull Vorgang vorgang) {
		if (nonNull(vorgang.getOrganisationseinheitenId())) {
			var recipients = userRemoteService.getRecipients(vorgang.getOrganisationseinheitenId());
			emailRemoteService.sendEmail(buildUserEmail(recipients, MAIL_SUBJECT_TEMPLATE.formatted(vorgang.getVorgangName())));
		}
	}

	UserEmail buildUserEmail(List<Recipient> recipients, String subject) {
		return UserEmail.builder().recipients(recipients).subject(subject).body(MAIL_BODY).build();
	}
}