/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.notification.postfach;

import java.util.Map;

import de.ozgcloud.notification.vorgang.VorgangTestFactory;

public class PostfachNachrichtTestFactory {

	static final String MESSAGE = "Lorem Ipsum";
	static final String SUBJECT = "delores est";

	public static final PostfachNachricht create() {
		return createBuilder().build();
	}

	public static final PostfachNachricht.PostfachNachrichtBuilder createBuilder() {
		return PostfachNachricht.builder()
				.vorgangId(VorgangTestFactory.ID)
				.postfachId(VorgangTestFactory.POSTFACH_ID)
				.postfachAddress(PostfachAddressTestFactory.create())
				.mailBody(MESSAGE)
				.subject(SUBJECT);
	}

	public static final Map<String, Object> createAsMap() {
		return Map.of(
				PostfachNachricht.FIELD_VORGANG_ID, VorgangTestFactory.ID,
				PostfachNachricht.FIELD_POSTFACH_ID, VorgangTestFactory.POSTFACH_ID,
				PostfachNachricht.FIELD_POSTFACH_ADDRESS, createPostfachAddressMap(),
				PostfachNachricht.FIELD_SUBJECT, SUBJECT,
				PostfachNachricht.FIELD_MESSAGE, MESSAGE,
				PostfachNachricht.FIELD_REPLY_OPTION, PostfachNachricht.DEFAULT_REPLY_OPTION);
	}
	
	public static final Map<String, Object> createPostfachAddressMap(){
		return Map.of(PostfachAddress.TYPE_FIELD, PostfachAddressTestFactory.TYPE,
				PostfachAddress.VERSION_FIELD, PostfachAddressTestFactory.VERSION,
				PostfachAddress.IDENTIFIER_FIELD, createIdentifierMap());
	}
	
	public static final Map<String, Object> createIdentifierMap(){
		return Map.of(PostfachNachricht.FIELD_POSTFACH_ID, PostfachAddressTestFactory.STRING_BASED_IDENTIFIER_POSTFACH_ID_VALUE);
	}
}