/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.notification.user;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.command.VorgangCreatedEvent;
import de.ozgcloud.notification.vorgang.VorgangId;
import de.ozgcloud.notification.vorgang.VorgangService;
import de.ozgcloud.notification.vorgang.VorgangTestFactory;

class UserNotificationEventListenerTest {

	@InjectMocks
	private UserNotificationEventListener userNotificationEventListener;

	@Mock
	private UserNotificationService userNotificationService;
	@Mock
	private VorgangService vorgangService;

	@DisplayName("On Vorgang created")
	@Nested
	class TestOnVorgangCreated {

		private static final VorgangCreatedEvent EVENT = new VorgangCreatedEvent(VorgangTestFactory.ID.toString());

		@DisplayName("with existing orgaId")
		@Nested
		class TestWithOrgaId {

			@BeforeEach
			void initMock() {
				when(vorgangService.getVorgang(any())).thenReturn(VorgangTestFactory.create());
			}

			@Test
			void shouldCallVorgangService() {
				userNotificationEventListener.onVorgangCreated(EVENT);

				verify(vorgangService).getVorgang(VorgangId.from(EVENT.getSource()));
			}

			@Test
			void shouldNotifyWithOrganisationeinheitIds() {
				var vorgang = VorgangTestFactory.create();
				when(vorgangService.getVorgang(any())).thenReturn(vorgang);

				userNotificationEventListener.onVorgangCreated(EVENT);

				verify(userNotificationService).sendNotification(vorgang);
			}
		}

	}
}