/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.notification.user;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.notification.NotificationManagerCallContextAttachingInterceptor;
import de.ozgcloud.notification.vorgang.VorgangTestFactory;
import de.ozgcloud.user.grpc.recipient.RecipientServiceGrpc.RecipientServiceBlockingStub;

class UserRemoteServiceTest {

	@InjectMocks
	private UserRemoteService remoteService;

	@Mock
	private RecipientServiceBlockingStub stub;
	@Mock
	private UserRecipientMapper mapper;

	@Nested
	class TestRequestRecipients {

		@BeforeEach
		void initTest() {
			when(stub.findRecipientByOrganisationsEinheitId(any())).thenReturn(GrpcFindRecipientRequestTestFactory.create());
			when(stub.withInterceptors(any())).thenReturn(stub);
		}

		@Test
		void shouldCallMapper() {
			remoteService.getRecipients(VorgangTestFactory.ORGANISATIONS_EINHEIT_ID);

			verify(mapper).fromGrpc(GrpcFindRecipientRequestTestFactory.GRPC_RECIPIENT);
		}

		@Test
		void shouldUseInterceptor() {
			remoteService.getRecipients(VorgangTestFactory.ORGANISATIONS_EINHEIT_ID);

			verify(stub).withInterceptors(any(NotificationManagerCallContextAttachingInterceptor.class));
		}
	}
}