/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.notification.vorgang;

import java.time.ZonedDateTime;
import java.util.UUID;

import de.ozgcloud.notification.postfach.PostfachAddressTestFactory;

public class VorgangTestFactory {

	public static final VorgangId ID = VorgangId.from(UUID.randomUUID().toString());

	public static final String VORGANG_NAME = "Antrag auf Toast";
	public static final String VORGANG_NUMMER = "1234";
	public static final String CREATED_AT_STR = "2001-04-01T10:30:00Z";
	public static final ZonedDateTime CREATED_AT = ZonedDateTime.parse(CREATED_AT_STR);

	public static final String POSTFACH_ID = UUID.randomUUID().toString();
	public static final String FORM_ENGINE_NAME = "deluxeEngine";
	public static final String ORGANISATIONS_EINHEIT_ID = "1234567889";

	public static Vorgang create() {
		return createBuilder().build();
	}

	public static Vorgang.VorgangBuilder createBuilder() {
		return Vorgang.builder()
				.id(ID)
				.vorgangName(VORGANG_NAME)
				.vorgangNummer(VORGANG_NUMMER)
				.createdAt(CREATED_AT)
				.postfachId(POSTFACH_ID)
				.postfachAddress(PostfachAddressTestFactory.create())
				.formEngineName(FORM_ENGINE_NAME)
				.organisationseinheitenId(ORGANISATIONS_EINHEIT_ID);
	}

}
