{{/* vim: set filetype=mustache: */}}

{{/* Namespace */}}
{{- define "app.namespace" -}}
{{- if gt (len (.Release.Namespace)) 63 -}}
{{- fail (printf ".Release.Namespace %s ist zu lang (max. 63 Zeichen)" .Release.Namespace) -}}
{{- end -}}
{{ printf "%s" .Release.Namespace }}
{{- end -}}

{{/* Chart: Name + Version */}}
{{- define "app.chart" -}}
{{- if gt (len (printf "%s-%s" .Chart.Name .Chart.Version)) 63 -}}
{{- fail (printf ".Chart.Name-.Chart.Version %s-%s ist zu lang (max. 63 Zeichen)" .Chart.Name .Chart.Version) -}}
{{- end -}}
{{ printf "%s-%s" .Chart.Name .Chart.Version }}
{{- end -}}

{{/* Managed-by -> On Helm, this value is always Helm */}}
{{- define "app.managedBy" -}}
{{- if gt (len (.Release.Service)) 63 -}}
{{- fail (printf ".Release.Service %s ist zu lang (max. 63 Zeichen)" .Release.Service) -}}
{{- end -}}
{{ printf "%s" .Release.Service }}
{{- end -}}

{{/* Default Labels: Helm recommended best-practice labels https://helm.sh/docs/chart_best_practices/labels/ */}}
{{- define "app.defaultLabels" }}
app.kubernetes.io/instance: vorgang-manager
app.kubernetes.io/managed-by: {{ include "app.managedBy" . }}
app.kubernetes.io/name: {{ .Release.Name }}
app.kubernetes.io/namespace: {{ include "app.namespace" . }}
app.kubernetes.io/part-of: ozgcloud
app.kubernetes.io/version: {{ .Chart.Version }}
helm.sh/chart: {{ include "app.chart" . }}
{{- end -}}

{{- define "app.matchLabels" }}
app.kubernetes.io/name: {{ .Release.Name }}
app.kubernetes.io/namespace: {{ include "app.namespace" . }}
{{- end -}}

{{- define "app.imagePullSecret" }}
{{- with .Values.imageCredentials }}
{{- printf "{\"auths\":{\"%s\":{\"username\":\"%s\",\"password\":\"%s\",\"email\":\"%s\",\"auth\":\"%s\"}}}" .registry .username .password .email (printf "%s:%s" .username .password | b64enc) | b64enc }}
{{- end }}
{{- end }}

{{- define "app.envSpringProfiles" }}
{{- if (.Values.env).overrideSpringProfiles -}}
{{ printf "%s" (.Values.env).overrideSpringProfiles }}
{{- else -}}
{{ printf "oc, %s" (include "app.ozgcloudEnvironment" . ) }}
{{- end -}}
{{- end -}}

{{- define "app.ozgcloudEnvironment" -}}
{{- required "ozgcloud.environment muss angegeben sein" (.Values.ozgcloud).environment -}}
{{- end -}}

{{- define "app.vorgangManagerDatabase" -}}
{{- if (.Values.database).databaseName -}}
{{  .Values.database.databaseName }}
{{- else -}}
{{ printf "vorgang-manager-database" }}
{{- end -}}
{{- end -}}

{{- define "app.grpc_client_user-manager_address" -}}
{{ printf "%s.%s:9000" .Values.usermanagerName .Release.Namespace }}
{{- end -}}

{{- define "app.ozgcloud_migration_user-manager_address" -}}
{{ printf "http://%s.%s:8080/migration/user" .Values.usermanagerName .Release.Namespace }}
{{- end -}}

{{- define "app.ozgcloud_vorgangmanager_address" -}}
{{ printf "dns://%s.%s:9090" .Values.vorgangmanagerName .Release.Namespace }}
{{- end -}}

{{- define "app.databaseTlsCert" -}}
{{- if ((.Values.database).tls).secretName -}}
{{  .Values.database.tls.secretName }}
{{- else -}}
{{  printf "ozg-mongodb-tls-cert" }}
{{- end -}}
{{- end -}}

{{- define "app.databaseSecretName" -}}
{{- if (.Values.database).secretName -}}
{{  .Values.database.secretName }}
{{- else -}}
{{  printf "ozg-mongodb-admin-vorgang-manager-user" }}
{{- end -}}
{{- end -}}

{{- define "app.serviceAccountName" -}}
{{ printf "%s" ( (.Values.serviceAccount).name | default "vorgang-manager-service-account" ) }}
{{- end -}}