/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.clientattribute;

import static java.lang.annotation.RetentionPolicy.*;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import jakarta.validation.Constraint;
import jakarta.validation.ConstraintValidator;
import jakarta.validation.ConstraintValidatorContext;
import jakarta.validation.Payload;

@Constraint(validatedBy = ClientAttributeHasValueValidator.class)
@Target(ElementType.TYPE)
@Retention(RUNTIME)
@Documented
public @interface ClientAttributeHasValueConstraint {

	String message() default "validation_field_value_missingOrRedundance";

	Class<?>[] groups() default {};

	Class<? extends Payload>[] payload() default {};
}

class ClientAttributeHasValueValidator implements ConstraintValidator<ClientAttributeHasValueConstraint, ClientAttribute> {

	@Override
	public boolean isValid(ClientAttribute value, ConstraintValidatorContext context) {
		return hasExactOneValue(value);
	}

	private boolean hasExactOneValue(ClientAttribute value) {
		return value.getIntValue().isPresent() ^
				value.getStringValue().isPresent() ^
				value.getDoubleValue().isPresent() ^
				value.getBoolValue().isPresent();

	}
}
