/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.command;

import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.NullValuePropertyMappingStrategy;

import de.ozgcloud.vorgang.grpc.command.GrpcCommandResponse;
import de.ozgcloud.vorgang.grpc.command.GrpcOrder;

@Mapper(uses = CommandBodyMapper.class, //
		nullValuePropertyMappingStrategy = NullValuePropertyMappingStrategy.IGNORE, //
		nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS, //
		collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED)
public interface GrpcCommandResponseMapper {
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "mergeCommand", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "messageCodeBytes", ignore = true)
	@Mapping(target = "responseCodeValue", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "allFields", ignore = true)
	@Mapping(target = "messageParametersList", source = "messageParameters")
	@Mapping(target = "command.orderString", source = "command.order")
	GrpcCommandResponse toGrpc(CommandResponse response);

	default GrpcOrder orderMapping(String order) {
		try {
			return GrpcOrder.valueOf(order);
		} catch (IllegalArgumentException e) {
			return GrpcOrder.UNDEFINED;
		}
	}
}
