/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.common.migration;

import java.util.List;

import org.springframework.data.mongodb.core.MongoOperations;

import io.mongock.api.annotations.ChangeUnit;
import io.mongock.api.annotations.Execution;
import io.mongock.api.annotations.RollbackExecution;

@ChangeUnit(id = "2023-11-29 15:30:00 OZG-4191-OZG-4630", order = "M008", author = "mkuester", runAlways = true)
public class M008_UpdateMailServiceClientNameInGridFs { // NOSONAR

	static final String GRID_FS_FILE_COLLECTION = "fs.files";
	static final String OLD_CLIENT_NAME = "MailService";
	static final String NEW_CLIENT_NAME = "OzgCloud_NachrichtenManager";

	@Execution
	public void doMigration(MongoOperations db) {
		db.getCollection(GRID_FS_FILE_COLLECTION).updateMany(
				RenameUtil.createMetadataClientMatchingDocument(OLD_CLIENT_NAME),
				List.of(
						RenameUtil.createSetFilenameOperation(OLD_CLIENT_NAME, NEW_CLIENT_NAME),
						RenameUtil.createSetClientDocument(NEW_CLIENT_NAME)));
	}

	@RollbackExecution
	public void rollback() {
		// kein rollback implementiert
	}
}