/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.common.migration;

import java.util.Map;

import org.bson.Document;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.data.mongodb.core.query.Update;
import org.springframework.data.mongodb.core.query.UpdateDefinition;

class RenameUtil {

	private final static String SET_OPERATOR = "$set";
	private final static String REPLACE_ONE_OPERATOR = "$replaceOne";

	static final String CLIENT_KEY = "client";

	// VorgangAttachedItem
	public static Query createFindVorgangAttachedItemQuery(String clientName) {
		return Query.query(Criteria.where(CLIENT_KEY).is(clientName));
	}

	public static Update createVorgangAttachedItemUpdate(String newClientName) {
		return new Update().set(CLIENT_KEY, newClientName);
	}

	// GridFsFiles
	static final String FILENAME_KEY = "filename";
	static final String METADATA_KEY = "metadata";

	public static Document createMetadataClientMatchingDocument(String clientName) {
		return new Document(Map.of(METADATA_KEY + "." + CLIENT_KEY, clientName));
	}

	public static Document createSetFilenameOperation(String oldClientName, String newClientName) {
		return new Document(Map.of(SET_OPERATOR,
				Map.of(FILENAME_KEY,
						Map.of(REPLACE_ONE_OPERATOR,
								Map.of("input", "$" + FILENAME_KEY,
										"find", "/" + oldClientName + "/",
										"replacement", "/" + newClientName + "/")))));
	}

	public static Document createSetClientDocument(String newClientName) {
		return new Document(Map.of(SET_OPERATOR, Map.of(RenameUtil.METADATA_KEY + "." + CLIENT_KEY, newClientName)));
	}

	// Vorgang ClientAttributes
	static final String CLIENT_ATTRIBUTES_KEY = "clientAttributes";

	public static Query createFindVorgangClientAttributesQuery(String clientName) {
		return new Query(Criteria.where(CLIENT_ATTRIBUTES_KEY + "." + clientName).exists(true));
	}

	public static UpdateDefinition createVorgangClientAttributesClientUpdate(String oldClientName, String newClientName) {
		var update = new Update();
		update.rename(CLIENT_ATTRIBUTES_KEY + "." + oldClientName, CLIENT_ATTRIBUTES_KEY + "." + newClientName);
		return update;
	}
}