/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.common.search;

import jakarta.validation.Valid;
import javax.net.ssl.SSLContext;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.ssl.SslBundles;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.elasticsearch.client.ClientConfiguration;
import org.springframework.data.elasticsearch.client.elc.ElasticsearchConfiguration;
import org.springframework.data.elasticsearch.support.HttpHeaders;

import lombok.SneakyThrows;

@Configuration
@ConditionalOnProperty(prefix = "ozgcloud.elasticsearch", name = "address")
public class SearchConfig extends ElasticsearchConfiguration {

	@Autowired
	@Valid
	private SearchProperties properties;

	@Autowired
	private SslBundles sslBundles;

	@SneakyThrows
	@Override
	public ClientConfiguration clientConfiguration() {
		var configurationBuilder = ClientConfiguration.builder().connectedTo(properties.getAddress());
		if (properties.isUseSsl()) {
			configurationBuilder.usingSsl(createSslContext());
		}
		return configurationBuilder
				.withDefaultHeaders(buildHeaders())
				.withBasicAuth(properties.getUsername(), properties.getPassword())
				.build();
	}

	SSLContext createSslContext() {
		return sslBundles.getBundle("es-root-ca").createSslContext();
	}

	HttpHeaders buildHeaders() {
		var headers = new HttpHeaders();
		headers.add("Accept", "application/vnd.elasticsearch+json;compatible-with=7");
		headers.add("Content-Type", "application/vnd.elasticsearch+json;compatible-with=7");
		return headers;
	}
}
