/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.common.search;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationListener;
import org.springframework.context.annotation.Profile;
import org.springframework.context.event.ContextRefreshedEvent;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;

import de.ozgcloud.vorgang.vorgang.Vorgang;
import de.ozgcloud.vorgang.vorgang.VorgangService;
import lombok.extern.log4j.Log4j2;

@Component
@ConditionalOnProperty(prefix = "ozgcloud.elasticsearch", name = "address")
@Profile("initSearchIndex")
@Async
@Log4j2
public class SearchIndexInitializer implements ApplicationListener<ContextRefreshedEvent> {
	@Autowired
	private VorgangService vorgangService;

	@Autowired
	private SearchService searchService;

	@Autowired
	private ApplicationContext context;

	@Override
	public void onApplicationEvent(ContextRefreshedEvent event) {
		LOG.info("Start filling up index");
		vorgangService.findAll().forEach(this::addOrUpdateVorgangToIndex);

		LOG.info("Successful filled up index - exiting");
		stopApplication();
	}

	private void addOrUpdateVorgangToIndex(Vorgang vorgang) {
		searchService.addVorgang(vorgang);
	}

	void stopApplication() {
		SpringApplication.exit(context, () -> 0);
	}

}
