/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.files;

import java.io.InputStream;
import java.util.Collection;
import java.util.List;
import java.util.Optional;
import java.util.concurrent.CompletableFuture;
import java.util.stream.Stream;
import java.util.stream.StreamSupport;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import com.mongodb.client.gridfs.model.GridFSFile;

import de.ozgcloud.nachrichten.postfach.BinaryFileService;

//TODO make service package protected, as soon PersistPostfachMailByCommandService and FileStreamService is gone
@Service
public class FileService implements BinaryFileService {
	public static final int CHUNK_SIZE = 255 * 1024;

	@Autowired
	private EingangFilesRepository repository;
	@Autowired
	private BinaryFileRepository binaryFileRepository;

	@Autowired
	private FileIdMapper fileIdMapper;

	public List<OzgFile> getAttachments(String eingangId) {
		return repository.findAttachmentsByEingangId(eingangId);
	}

	public List<OzgFile> getRepresentations(String eingangId) {
		return repository.findRepresentationsByEingangId(eingangId);
	}

	public CompletableFuture<FileId> uploadFileStream(UploadedFilesReference ref, OzgFile file, Optional<String> userId, InputStream content) {
		return uploadFile(ref, file, userId, content);
	}

	@Async
	public CompletableFuture<FileId> uploadFileStreamAsync(UploadedFilesReference ref, OzgFile file, Optional<String> userId, InputStream content) {
		return uploadFile(ref, file, userId, content);
	}

	CompletableFuture<FileId> uploadFile(UploadedFilesReference ref, OzgFile file, Optional<String> userId, InputStream content) {
		return CompletableFuture.completedFuture(binaryFileRepository.addContentStream(ref, file, userId, content));
	}

	public InputStream getUploadedFileStream(FileId fileId) {
		return binaryFileRepository.getFileContent(fileId);
	}

	@Override
	public InputStream getUploadedFileStream(de.ozgcloud.nachrichten.postfach.FileId fileId) {
		return binaryFileRepository.getFileContent(FileId.from(fileId.toString()));
	}

	@Override
	public GridFSFile getFile(de.ozgcloud.nachrichten.postfach.FileId fileId) {
		return binaryFileRepository.getFile(FileId.from(fileId.toString()));
	}

	public Stream<OzgFile> findFilesMetaData(Collection<FileId> ids) {
		return StreamSupport.stream(binaryFileRepository.getAll(mapFileIdToString(ids)).spliterator(), false);
	}

	private Iterable<String> mapFileIdToString(Collection<FileId> ids) {
		return ids.stream().map(fileIdMapper::toString).toList();
	}

	public void deleteAllByVorgang(String vorgangId) {
		binaryFileRepository.deleteAllByVorgang(vorgangId);
	}
}