/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.registry;

import java.util.List;
import java.util.Optional;

import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import lombok.extern.log4j.Log4j2;

@Service
@Log4j2
class RegistryService {
	@Value(value = "${ozgcloud.vorgang-manager.address:#{null}}")
	private Optional<String> vorgangManagerAddress;

	@Autowired
	private ZufiRemoteService zufiRemoteService;

	public void registerVorgangManager(List<String> supportedOrganisationsEinheiten) {
		try {
			register(supportedOrganisationsEinheiten);
		} catch (Exception e) {
			LOG.error("Error registering this VorgangsManager.", e);
		}
	}

	private void register(List<String> supportedOrganisationsEinheiten) {
		if (CollectionUtils.isNotEmpty(supportedOrganisationsEinheiten)) {
			registerAddress(supportedOrganisationsEinheiten, vorgangManagerAddress);
		} else {
			LOG.warn("No OrganistationsEinheitenIds provided. Not registering this VorgangsManager");
		}
	}

	void registerAddress(List<String> supportedOrganisationsEinheiten, Optional<String> vorgangManagerAddress) {
		vorgangManagerAddress.ifPresentOrElse(address -> {
			zufiRemoteService.registerVorgangManager(supportedOrganisationsEinheiten, address);
		}, () -> LOG.error("Property ozgcloud.vorgang-manager.address not set. Not registering this VorgangsManager"));
	}
}
