/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.system;

import java.util.Objects;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.info.BuildProperties;

import de.ozgcloud.vorgang.common.search.SearchService;
import io.grpc.stub.StreamObserver;
import net.devh.boot.grpc.server.service.GrpcService;

@GrpcService
public class SystemStatusGrpcService extends SystemStatusServiceGrpc.SystemStatusServiceImplBase {

	@Autowired(required = false)
	private SearchService searchService;

	@Autowired
	private BuildProperties buildProperties;

	@Override
	public void getSystemStatus(GrpcGetSystemStatusRequest grpcSystemStatusRequest, StreamObserver<GrpcGetSystemStatusResponse> responseObserver) {
		responseObserver.onNext(buildResponse());
		responseObserver.onCompleted();
	}

	private GrpcGetSystemStatusResponse buildResponse() {
		return GrpcGetSystemStatusResponse.newBuilder().setIsSearchServerAvailable(isSearchServiceAvailable()).setJavaVersion(getJavaVersion())
				.setBuildVersion(getBuildVersion()).build();
	}

	private boolean isSearchServiceAvailable() {
		return Objects.nonNull(searchService);
	}

	private String getJavaVersion() {
		return System.getProperty("java.version");
	}

	private String getBuildVersion() {
		return buildProperties.getVersion();
	}

}
