/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.user;

import static java.util.function.Predicate.*;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Profile;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import de.ozgcloud.vorgang.command.CommandService;
import lombok.extern.log4j.Log4j2;
import net.javacrumbs.shedlock.spring.annotation.SchedulerLock;

@Component
@Profile("!itcase")
@Log4j2
public class DeleteUserScheduler {

	@Autowired
	private UserService userService;
	@Autowired
	private CommandService commandService;

	 @Scheduled(cron = "${ozgcloud.user.cleanup.cron:0 0 1 * * *}")
	 @SchedulerLock(name = "DeleteUserScheduler")
	public void deleteUsers() {
		try {
			LOG.debug("Deleting inactive users.");
			userService.findInactiveUserIds().filter(not(commandService::existsCommandWithUserId)).forEach(userService::deleteInactiveUser);
		} catch (RuntimeException e) {
			LOG.error("Cannot delete inactive users.", e);
		}
	}
}
