/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.vorgang;

import java.util.Collection;

import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.springframework.beans.factory.annotation.Autowired;

import com.google.protobuf.ProtocolStringList;

import de.ozgcloud.vorgang.callcontext.CallContextUser;
import de.ozgcloud.vorgang.callcontext.CurrentUserService;

@Mapper(collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED)
abstract class FilterByMapper {

	@Autowired
	private CurrentUserService userService;

	@Mapping(target = "organisationseinheitId", ignore = true)
	@Mapping(target = "singleStatus", ignore = true)
	@Mapping(target = "organisationseinheitIds", expression = "java(getOrganisationEinheitenIds(filterBy))")
	@Mapping(target = "status", source = "statusList")
	@Mapping(target = "filterByOrganisationseinheitenId", expression = "java(isOrganisationEinheitenIdCheckNecessary(filterBy))")
	abstract FilterCriteria fromFilterBy(GrpcFilterBy filterBy);

	Collection<String> getOrganisationEinheitenIds(GrpcFilterBy filterBy) {
		return userService.findUser().map(CallContextUser::getOrganisatorischeEinheitenIds)
				.map(organisationEinheitenIds -> evaluateOrganisationEinheitenIds(organisationEinheitenIds, filterBy.getOrganisationseinheitIdList()))
				.orElse(filterBy.getOrganisationseinheitIdList());
	}

	private Collection<String> evaluateOrganisationEinheitenIds(Collection<String> idsByUser, ProtocolStringList idsByRequest) {
		if (!idsByRequest.isEmpty()) {
			return idsByRequest;
		} else {
			return idsByUser;
		}
	}

	boolean isOrganisationEinheitenIdCheckNecessary(GrpcFilterBy filterBy) {
		return userService.findUser().map(CallContextUser::isOrganisationEinheitenIdCheckNecessary)
				.map(isCheckNecessary -> evaluateIsCheckNecessary(isCheckNecessary, filterBy.getFilterByOrganisationseinheitenId()))
				.orElse(filterBy.getFilterByOrganisationseinheitenId());
	}

	private boolean evaluateIsCheckNecessary(boolean doCheckByUser, boolean doCheckByRequest) {
		if (doCheckByUser != doCheckByRequest) {
			return doCheckByRequest;
		} else {
			return doCheckByUser;
		}
	}
}