/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.vorgang;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;

import io.grpc.stub.StreamObserver;
import net.devh.boot.grpc.server.service.GrpcService;

@GrpcService
class GrpcVorgangService extends VorgangServiceGrpc.VorgangServiceImplBase {

	@Autowired
	private VorgangService vorgangService;
	@Autowired
	private VorgangHeaderService vorgangHeaderService;
	@Autowired
	private EingangMapper eingangMapper;
	@Autowired
	private VorgangHeaderMapper vorgangHeaderMapper;
	@Autowired
	private VorgangWithEingangMapper vorgangWithEingangMapper;
	@Autowired
	private FindVorgangRequestMapper findVorgangRequestMapper;
	@Autowired
	private FilterByMapper filterByMapper;
	@Autowired
	private IncomingFileMapper incomingFileMapper;
	@Autowired
	private IncomingFileGroupMapper incomingFileGroupMapper;

	@Override
	public void startCreation(GrpcCreateVorgangRequest request, StreamObserver<GrpcCreateVorgangResponse> responseObserver) {
		GrpcCreateVorgangResponse response = buildCreateVorgangResponse(startVorgangCreation(request.getEingang()));

		responseObserver.onNext(response);
		responseObserver.onCompleted();
	}

	private Vorgang startVorgangCreation(GrpcEingang eingang) {
		return vorgangService.startCreation(eingangMapper.fromGrpc(eingang));
	}

	private GrpcCreateVorgangResponse buildCreateVorgangResponse(Vorgang vorgang) {
		return GrpcCreateVorgangResponse.newBuilder().setVorgangId(vorgang.getId()).setMessage("ok").build();
	}

	@Override
	public void finishCreation(GrpcFinishCreationRequest request, StreamObserver<GrpcFinishCreationResponse> responseObserver) {
		var attachments = request.getAttachmentsList().stream().map(incomingFileGroupMapper::mapGrpc).toList();
		var representations = request.getRepresentationsList().stream().map(incomingFileMapper::mapGrpc).toList();

		vorgangService.finishCreation(request.getVorgangId(), attachments, representations);

		responseObserver.onNext(buildFinishCreationResponse());
		responseObserver.onCompleted();
	}

	private GrpcFinishCreationResponse buildFinishCreationResponse() {
		return GrpcFinishCreationResponse.newBuilder().setMessage("ok").build();
	}

	@Override
	public void findVorgang(GrpcFindVorgangRequest request, StreamObserver<GrpcFindVorgangResponse> responseObserver) {
		var vorgangHeaderPage = vorgangHeaderService.findAll(findVorgangRequestMapper.fromFindVorgangRequest(request));

		responseObserver.onNext(buildFindVorgangResponse(vorgangHeaderPage));
		responseObserver.onCompleted();
	}

	private GrpcFindVorgangResponse buildFindVorgangResponse(Page<VorgangHeader> page) {
		var replyBuilder = page.getContent().stream()
				.map(vorgangHeaderMapper::toGrpcVorgangHeader)//
				.collect(GrpcFindVorgangResponse::newBuilder, GrpcFindVorgangResponse.Builder::addVorgang,
						(builder1, builder2) -> builder1.addAllVorgang(builder2.getVorgangList()));

		return replyBuilder.setTotal(page.getTotalElements()).build();
	}

	@Override
	public void findVorgangWithEingang(GrpcFindVorgangWithEingangRequest request,
			StreamObserver<GrpcFindVorgangWithEingangResponse> responseObserver) {
		var vorgang = vorgangService.getById(request.getId(), filterByMapper.fromFilterBy(request.getFilterBy()));

		responseObserver.onNext(buildFindVorgangWithEingangReply(vorgang));
		responseObserver.onCompleted();
	}

	private GrpcFindVorgangWithEingangResponse buildFindVorgangWithEingangReply(Vorgang vorgang) {
		return GrpcFindVorgangWithEingangResponse.newBuilder()
				.setVorgangWithEingang(vorgangWithEingangMapper.toVorgangWithEingang(vorgang))
				.build();
	}
}