/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.attached_item;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.springframework.data.mongodb.core.MongoOperations;

import com.mongodb.client.result.DeleteResult;
import com.mongodb.client.result.UpdateResult;

import de.ozgcloud.vorgang.common.db.CollisionVerifier;

class VorgangAttachedItemCustomRepositoryImplTest {

	@Spy
	@InjectMocks
	private VorgangAttachedItemCustomRepositoryImpl repository;

	@Mock
	private MongoOperations mongoOperations;
	@Mock
	private CollisionVerifier collisionVerifier;

	@Nested
	class TestDelete {

		@Test
		void shouldCallCollisionVerifier() {
			var deleteResult = mock(DeleteResult.class);
			when(mongoOperations.remove(any(), anyString())).thenReturn(deleteResult);

			repository.delete(VorgangAttachedItemTestFactory.ID, VorgangAttachedItemTestFactory.VERSION);

			verify(collisionVerifier).verify(deleteResult, VorgangAttachedItemTestFactory.ID);
		}
	}

	@Nested
	class TestMarkAsDeleted {

		@Test
		void shouldCallCollisionVerifier() {
			var updateResult = mock(UpdateResult.class);
			when(mongoOperations.updateFirst(any(), any(), anyString())).thenReturn(updateResult);

			repository.updateDeleted(true, VorgangAttachedItemTestFactory.ID, VorgangAttachedItemTestFactory.VERSION);

			verify(collisionVerifier).verify(updateResult, VorgangAttachedItemTestFactory.ID);
		}
	}
}