/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.attached_item;

import static org.assertj.core.api.Assertions.*;

import org.apache.commons.lang3.StringUtils;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.context.ApplicationEventPublisher;

import de.ozgcloud.common.test.ITCase;
import de.ozgcloud.vorgang.command.CommandTestFactory;
import jakarta.validation.ConstraintViolationException;

@ITCase
class VorgangAttachedItemServiceITCase {

	@Autowired
	private VorgangAttachedItemService service;

	@MockBean
	private VorgangAttachedItemRepository repository;
	@MockBean
	private ApplicationEventPublisher eventPublisher;

	@Nested
	class TestCreate {
		@Test
		void shouldDenyMissingClientName() {
			var item = VorgangAttachedItemTestFactory.createBuilder().client(StringUtils.EMPTY).build();

			assertThatThrownBy(() -> service.create(CommandTestFactory.ID, item))
					.isInstanceOf(ConstraintViolationException.class);
		}

		@Test
		void shouldDenyMissingVorgangId() {
			var item = VorgangAttachedItemTestFactory.createBuilder().vorgangId(StringUtils.EMPTY).build();

			assertThatThrownBy(() -> service.create(CommandTestFactory.ID, item))
					.isInstanceOf(ConstraintViolationException.class);
		}

		@Test
		void shouldDenyMissingItemName() {
			var item = VorgangAttachedItemTestFactory.createBuilder().itemName(StringUtils.EMPTY).build();

			assertThatThrownBy(() -> service.create(CommandTestFactory.ID, item))
					.isInstanceOf(ConstraintViolationException.class);
		}
	}

}
