/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.attached_item;

import java.util.List;
import java.util.Map;
import java.util.UUID;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.common.binaryfile.FileId;
import de.ozgcloud.vorgang.vorgang.VorgangTestFactory;

public class VorgangAttachedItemTestFactory {

	public static final boolean DELETED = true;

	public static final String ID = UUID.randomUUID().toString();
	public static final long VERSION = 1L;

	public static final String CLIENT = LoremIpsum.getInstance().getFirstName() + "Client";
	public static final String ITEM_NAME = "test";

	public static final String ITEM_FIELD_NAME = "number";
	public static final Integer ITEM_FIELD_INT_VALUE = 42;
	public static final String ITEM_FIELD_STRING_VALUE = "73";

	public static final String FIELD_NAME_VORGANG_ID = "vorgangId";
	public static final String FIELD_NAME_VORGANG_VERSION = "vorgangVersion";
	public static final String FIELD_NAME_CREATED_AT = "createdAt";
	public static final String CREATED_BY_FIELD_NAME = "createdBy";
	public static final String CREATED_BY_NAME_FIELD_NAME = "createdByName";
	public static final String BETREFF_FIELD_NAME = "betreff";
	public static final String BESCHREIBUNG_FIELD_NAME = "beschreibung";
	public static final String ATTACHMENTS_FIELD_NAME = "attachments";

	public static final FileId ATTACHMENT_ID = FileId.createNew();
	static final List<FileId> ATTACHMENTS = List.of(ATTACHMENT_ID, ATTACHMENT_ID);

	static final Map<String, Object> STRING_MAP = Map.of(ITEM_FIELD_NAME, ITEM_FIELD_STRING_VALUE);

	public static VorgangAttachedItem create() {
		return createBuilder().build();
	}

	public static VorgangAttachedItem.VorgangAttachedItemBuilder createBuilder() {
		return VorgangAttachedItem.builder()
				.id(ID)
				.vorgangId(VorgangTestFactory.ID)
				.version(VERSION)
				.client(CLIENT)
				.itemName(ITEM_NAME)
				.deleted(false)
				.item(STRING_MAP);
	}

	public static Map<String, Object> asMap() {
		return Map.of(VorgangAttachedItem.FIELDNAME_CLIENT, CLIENT,
				VorgangAttachedItem.FIELDNAME_ID, ID,
				VorgangAttachedItem.FIELDNAME_VORGANG_ID, VorgangTestFactory.ID,
				VorgangAttachedItem.FIELDNAME_VERSION, VorgangAttachedItemTestFactory.VERSION,
				VorgangAttachedItem.FIELDNAME_ITEM_NAME, ITEM_NAME,
				VorgangAttachedItem.FIELDNAME_ITEM, STRING_MAP);
	}
}