/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.clientattribute;

import static org.assertj.core.api.Assertions.*;

import java.util.Optional;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.mock.mockito.MockBean;

import de.ozgcloud.common.test.ITCase;
import de.ozgcloud.vorgang.vorgang.VorgangTestFactory;
import jakarta.validation.ConstraintViolationException;

@ITCase
class ClientAttributeServiceITCase {

	@Autowired
	private ClientAttributeService service;

	@MockBean
	private ClientAttributeRepository repository;

	@Nested
	class TestValidateAttribte {
		@Test
		void shouldDenyMissingClientName() {
			var attribute = ClientAttributeTestFactory.createBuilder().clientName(null).build();

			assertThatThrownBy(() -> service.set(VorgangTestFactory.ID, attribute)).isInstanceOf(ConstraintViolationException.class);
		}

		@Test
		void shouldDenyMissingAttributeName() {
			var attribute = ClientAttributeTestFactory.createBuilder().attributeName(null).build();

			assertThatThrownBy(() -> service.set(VorgangTestFactory.ID, attribute)).isInstanceOf(ConstraintViolationException.class);
		}

		@Test
		void shouldAnyMissingValue() {
			var attribute = ClientAttributeTestFactory.createBuilder().intValue(Optional.empty()).build();

			assertThatThrownBy(() -> service.set(VorgangTestFactory.ID, attribute)).isInstanceOf(ConstraintViolationException.class);
		}
	}

}
