/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.command;

import java.io.InputStream;
import java.nio.charset.Charset;
import java.util.function.Supplier;

import org.apache.commons.io.IOUtils;

import de.ozgcloud.nachrichten.postfach.AttachmentFile;
import de.ozgcloud.nachrichten.postfach.AttachmentFile.AttachmentFileBuilder;

public class AttachmentFileTestFactory {

	public static final String ATTACHMENT_NAME = "test.txt";
	public static final String CONTENT_TYPE = "text/plain";

	public static final String BASE64_CONTENT = "dGVzdA==";
	public static final String CONTENT = "test";
	public static final long SIZE = 4L;
	public static final Supplier<InputStream> CONTENT_SUPPLIER = () -> IOUtils.toInputStream(CONTENT, Charset.defaultCharset());
	public static final Supplier<InputStream> BASE64_CONTENT_SUPPLIER = () -> IOUtils.toInputStream(BASE64_CONTENT, Charset.defaultCharset());

	public static AttachmentFile create() {
		return createBuilder().build();
	}

	public static AttachmentFileBuilder createBuilder() {
		return AttachmentFile.builder()
				.name(ATTACHMENT_NAME)
				.contentType(CONTENT_TYPE)
				.content(CONTENT_SUPPLIER);
	}
}
