/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.command;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.time.ZonedDateTime;
import java.util.stream.Stream;

import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.command.Command;
import de.ozgcloud.vorgang.vorgang.VorgangTestFactory;

class CommandDeletionSchedulerTest {

	@InjectMocks
	@Spy
	private CommandDeletionScheduler scheduler;
	@Mock
	private CommandService commandService;

	private ZonedDateTime cleanupThreshold = ZonedDateTime.now().minusMinutes(CommandDeletionScheduler.CLEANUP_THRESHOLD_MINUTES);

	@Test
	void shouldCallGetCleanupThreshold() {
		scheduler.deleteCommands();

		verify(scheduler).getCleanupThreshold();
	}

	@Test
	void shouldFindFinishedCommands() {
		doReturn(cleanupThreshold).when(scheduler).getCleanupThreshold();

		scheduler.deleteCommands();

		verify(commandService).findFinishedVorgangLoeschenCommandsOlderThen(cleanupThreshold);
	}

	@Test
	void shouldCallCommandService() {
		Stream<Command> commands = Stream.of(CommandTestFactory.create(), CommandTestFactory.create());
		when(commandService.findFinishedVorgangLoeschenCommandsOlderThen(any())).thenReturn(commands);

		scheduler.deleteCommands();

		verify(commandService).deleteAllByVorgang(VorgangTestFactory.ID);
	}

	@Test
	void shouldCatchExceptionWhenFindMethodCalled() {
		doThrow(new RuntimeException()).when(commandService).findFinishedVorgangLoeschenCommandsOlderThen(any());

		scheduler.deleteCommands();

		verify(commandService, never()).deleteAllByVorgang(any());
	}

	@Test
	void shouldCatchExceptionWhenDeleteMethodCalled() {
		when(commandService.findFinishedVorgangLoeschenCommandsOlderThen(any())).thenReturn(Stream.of(CommandTestFactory.create()));
		doThrow(new RuntimeException()).when(commandService).deleteAllByVorgang(any());

		assertThatNoException().isThrownBy(scheduler::deleteCommands);
	}
}