/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.command;

import java.time.ZonedDateTime;
import java.util.Map;
import java.util.UUID;

import de.ozgcloud.command.CommandStatus;
import de.ozgcloud.vorgang.attached_item.VorgangAttachedItemTestFactory;
import de.ozgcloud.vorgang.callcontext.UserTestFactory;
import de.ozgcloud.vorgang.vorgang.VorgangTestFactory;

public class CommandTestFactory {

	public static final String ID = UUID.randomUUID().toString();
	public static final String CREATED_AT_STR = "2021-01-10T10:30:00Z";
	public static final ZonedDateTime CREATED_AT = ZonedDateTime.parse(CREATED_AT_STR);
	public static final String CREATED_BY = UserTestFactory.ID;
	public static final String CREATED_BY_NAME = UserTestFactory.NAME;
	public static final CommandStatus STATUS = CommandStatus.PENDING;

	public static final String RELATION_ID = VorgangAttachedItemTestFactory.ID;
	public static final long RELATION_VERSION = VorgangTestFactory.VERSION;

	public static final Order ORDER = Order.VORGANG_ANNEHMEN;
	public static final Map<String, Object> PREVIOUS_STATE = Map.of("test", "value");
	public static final String CREATED_RESOURCE = "createdResource";

	public static PersistedCommand create() {
		return createBuilder().build();
	}

	public static PersistedCommand.PersistedCommandBuilder createBuilder() {
		return PersistedCommand.builder()
				.id(ID)
				.vorgangId(VorgangTestFactory.ID)
				.createdAt(CREATED_AT)
				.createdBy(CREATED_BY)
				.createdByName(CREATED_BY_NAME)
				.status(STATUS)
				.relationId(RELATION_ID)
				.relationVersion(RELATION_VERSION)
				.previousState(PREVIOUS_STATE)
				.order(ORDER.name());
	}
}
