/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.command;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.vorgang.callcontext.CallContext;
import de.ozgcloud.vorgang.callcontext.CurrentUserService;
import de.ozgcloud.vorgang.callcontext.User;
import de.ozgcloud.vorgang.files.FileIdMapper;
import de.ozgcloud.vorgang.grpc.command.GrpcCreateCommandRequest;

class GrpcCreateCommandRequestMapperTest {

	@InjectMocks
	private GrpcCreateCommandRequestMapper mapper = Mappers.getMapper(GrpcCreateCommandRequestMapper.class);
	@Spy
	private CommandBodyMapper bodyMapper = Mappers.getMapper(CommandBodyMapper.class);
	@Mock
	private FileIdMapper fileIdMapper;
	@Mock
	private CurrentUserService userSerivce;

	@Nested
	class TestGrpcCreateVorgangCommandRequestToCreateVorgangCommandRequest {

		@Nested
		class TestMapCallContext {

			@Test
			void shouldMapCallContext() {

				CreateCommandRequest request = mapper.fromGrpc(
						GrpcCreateCommandRequestTestFactory.create());

				assertThat(request.getCallContext()).isNotNull();
			}

			@Test
			void shouldMapClient() {

				CreateCommandRequest request = mapper.fromGrpc(
						GrpcCreateCommandRequestTestFactory.create());

				CallContext callContext = request.getCallContext();
				assertThat(callContext.getClient()).isEqualTo(GrpcCallContextTestFactory.CLIENT);
			}

			@Test
			void shouldMapUserShouldNotBeNull() {

				CreateCommandRequest request = mapper.fromGrpc(
						GrpcCreateCommandRequestTestFactory.create());

				assertThat(request.getCallContext().getUser()).isNotNull();
			}

			@Test
			void shouldMapUserIdAndName() {

				CreateCommandRequest request = mapper.fromGrpc(
						GrpcCreateCommandRequestTestFactory.create());

				User user = request.getCallContext().getUser();

				assertThat(user.getId()).isEqualTo(GrpcUserTestFactory.ID);
				assertThat(user.getName()).isEqualTo(GrpcUserTestFactory.NAME);
			}
		}

		@Test
		void shouldMapVorgangId() {

			GrpcCreateCommandRequest grpcRequest = GrpcCreateCommandRequestTestFactory.create();

			CreateCommandRequest request = mapper.fromGrpc(grpcRequest);

			assertThat(request.getRelationId()).isEqualTo(GrpcCreateCommandRequestTestFactory.RELATION_ID);
		}

		@Nested
		class shouldMapOrder {

			@Test
			void fromOrderStringField() {
				GrpcCreateCommandRequest grpcRequest = GrpcCreateCommandRequestTestFactory.createBuilder().clearOrder().build();

				CreateCommandRequest request = mapper.fromGrpc(grpcRequest);

				assertThat(request.getOrder()).isEqualTo(GrpcCreateCommandRequestTestFactory.ORDER.name());
			}

			@Test
			void fromOrderField() {
				GrpcCreateCommandRequest grpcRequest = GrpcCreateCommandRequestTestFactory.createBuilder().clearOrderString().build();

				CreateCommandRequest request = mapper.fromGrpc(grpcRequest);

				assertThat(request.getOrder()).isEqualTo(GrpcCreateCommandRequestTestFactory.ORDER.name());
			}
		}
	}
}