/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.common.migration;

import static de.ozgcloud.vorgang.common.migration.M006_UpdateMailServiceClientNameInVorgangAttachedItem.*;
import static org.assertj.core.api.Assertions.*;

import org.bson.Document;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Query;

import de.ozgcloud.common.test.DataITCase;

@DataITCase
class M006_UpdateMailServiceClientNameInVorgangAttachedItemITCase {

	private static final Document OLD_CLIENT_NAME_VORGANG_ATTACHED_ITEM = RenameTestFactory.createVorgangAttachedItem(OLD_CLIENT_NAME);

	private final M006_UpdateMailServiceClientNameInVorgangAttachedItem migration = new M006_UpdateMailServiceClientNameInVorgangAttachedItem();

	@Autowired
	private MigrationDbTestUtils dbTestUtils;
	@Autowired
	private MongoTemplate template;

	@BeforeEach
	public void init() {
		dbTestUtils.dropVorgangAttachedItemCollection();
	}

	@DisplayName("Do migration")
	@Nested
	class TestDoMigration {

		@BeforeEach
		void init() {
			dbTestUtils.saveVorgangAttachedItem(OLD_CLIENT_NAME_VORGANG_ATTACHED_ITEM);
		}

		@Test
		void shouldUpdateClientName() {
			migration.doMigration(template);

			assertThat(getVorgangAttachedItem()).containsEntry(RenameUtil.CLIENT_KEY, NEW_CLIENT_NAME);
		}

		@Test
		void shouldKeeptOtherAttributes() {
			migration.doMigration(template);

			assertThat(getVorgangAttachedItem())
					.containsEntry(RenameTestFactory.ITEM_NAME_KEY, RenameTestFactory.ITEM_NAME_VALUE)
					.containsKey(RenameTestFactory.ITEM_KEY);
		}

		@Test
		void shouldKeepItemAttributes() {
			migration.doMigration(template);

			var item = (Document) getVorgangAttachedItem().get(RenameTestFactory.ITEM_KEY);
			assertThat(item).containsExactly(entry(RenameTestFactory.ITEM_ATTRIBUTE_KEY, RenameTestFactory.ITEM_ATTRIBUTE_VALUE));
		}

		private Document getVorgangAttachedItem() {
			return dbTestUtils.findVorgangAttachedItem(new Query()).get(0);
		}
	}
}