/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.common.search;

import static org.mockito.Mockito.*;

import javax.net.ssl.SSLContext;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import lombok.SneakyThrows;

class SearchConfigTest {

	@Spy
	@InjectMocks
	private SearchConfig searchConfig;

	@Mock
	private SearchProperties properties;

	@Nested
	class TestClientConfiguration {

		@BeforeEach
		void setup() {
			when(properties.getAddress()).thenReturn("address:9200");
			when(properties.getUsername()).thenReturn("username");
			when(properties.getPassword()).thenReturn("");
		}

	 	@Test
		void shouldCallGetAddress() {
			searchConfig.clientConfiguration();

			verify(properties).getAddress();
		}

		@Test
		void shouldCallBuildHeaders() {
			searchConfig.clientConfiguration();

			verify(searchConfig).buildHeaders();
		}

		@SneakyThrows
		@Test
		void shouldSetSslContext() {
			doReturn(mock(SSLContext.class)).when(searchConfig).createSslContext();
			when(properties.isUseSsl()).thenReturn(true);

			searchConfig.clientConfiguration();

			verify(searchConfig).createSslContext();
		}

	}

}
