/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.registry;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.util.Collections;
import java.util.List;
import java.util.Optional;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.springframework.test.util.ReflectionTestUtils;

class RegistryServiceTest {
	private static final String ORGANISATION_EINHEITEN_ID = "123456";
	private static final List<String> ORGANISATION_EINHEITEN_IDS = List.of(ORGANISATION_EINHEITEN_ID);
	private static final Optional<String> VORGANG_MANAGER_ADDRESS = Optional.of("address");

	@Spy
	@InjectMocks
	private RegistryService registryService;

	@Mock
	private ZufiRemoteService zufiRemoteService;

	@DisplayName("Test registering the VorgangManager")
	@Nested
	class TestRegistryVorgangManager {
		@BeforeEach
		void initVorgangManagerAddress() {
			ReflectionTestUtils.setField(registryService, "vorgangManagerAddress", VORGANG_MANAGER_ADDRESS);
		}

		@Test
		void shouldCallZuFiRemoteService() {
			registryService.registerVorgangManager(ORGANISATION_EINHEITEN_IDS);

			verify(zufiRemoteService).registerVorgangManager(anyList(), any());
		}

		@Test
		void shouldNotCallZuFiRemoteServiceOnEmptyOrganisationsEinheitenIds() {
			registryService.registerVorgangManager(Collections.emptyList());

			verify(zufiRemoteService, never()).registerVorgangManager(anyList(), any());
		}

		@Test
		void shouldNotCallServiceStub() {
			registryService.registerAddress(ORGANISATION_EINHEITEN_IDS, Optional.empty());

			verify(zufiRemoteService, never()).registerVorgangManager(any(), any());
		}
	}
}
