/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.statistic;

import java.util.Map;

import de.ozgcloud.vorgang.vorgang.Vorgang;

public class StatisticTestFactory {

	public static final Integer NEU_COUNT = 1;
	public static final Integer ANGENOMMEN_COUNT = 2;
	public static final Integer IN_BEARBEITUNG_COUNT = 3;
	public static final Integer BESCHIEDEN_COUNT = 4;
	public static final Integer ABGESCHLOSSEN_COUNT = 5;
	public static final Integer VERWORFEN_COUNT = 6;
	public static final Integer WEITERGELEITET_COUNT = 7;

	private static final Map<Vorgang.Status, Integer> BY_STATUS_MAP = Map.of(
			Vorgang.Status.NEU, NEU_COUNT,
			Vorgang.Status.ANGENOMMEN, ANGENOMMEN_COUNT,
			Vorgang.Status.IN_BEARBEITUNG, IN_BEARBEITUNG_COUNT,
			Vorgang.Status.BESCHIEDEN, BESCHIEDEN_COUNT,
			Vorgang.Status.ABGESCHLOSSEN, ABGESCHLOSSEN_COUNT,
			Vorgang.Status.VERWORFEN, VERWORFEN_COUNT,
			Vorgang.Status.WEITERGELEITET, WEITERGELEITET_COUNT);

	public static final String FIELD_PATH_ALIAS = "countByPathAlias";
	public static final Integer FIELD_PATH_VALUE = 10;

	public static final Map<String, Integer> BY_PATH_MAP = Map.of(FIELD_PATH_ALIAS, FIELD_PATH_VALUE);

	public static final Map<String, Boolean> FIELD_EXISTS_MAP = Map.of(FIELD_PATH_ALIAS, true);

	public static Statistic create() {
		return createBuilder().build();
	}

	public static Statistic.StatisticBuilder createBuilder() {
		return Statistic.builder()
				.countByStatus(BY_STATUS_MAP)
				.countResult(BY_PATH_MAP)
				.existsResult(FIELD_EXISTS_MAP);
	}
}