/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.user;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.stream.Stream;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.vorgang.command.CommandService;

class DeleteUserSchedulerTest {

	@InjectMocks
	private DeleteUserScheduler scheduler;

	@Mock
	private UserService service;
	@Mock
	private CommandService commandService;

	@Test
	void shouldCallFindInactiveUserIds() {
		when(service.findInactiveUserIds()).thenReturn(Stream.empty());

		scheduler.deleteUsers();

		verify(service).findInactiveUserIds();
	}

	@Test
	void shouldCallExistsCommandWithUserIds() {
		var userId = "userId";
		when(service.findInactiveUserIds()).thenReturn(Stream.of(userId));

		scheduler.deleteUsers();

		verify(commandService).existsCommandWithUserId(userId);
	}

	@Test
	void shouldCallDeleteInactiveUser() {
		var userId = "userId";
		when(service.findInactiveUserIds()).thenReturn(Stream.of(userId));

		scheduler.deleteUsers();

		verify(service).deleteInactiveUser(userId);
	}

	@Nested
	class TestCatchException {

		@Test
		void shouldCatchFindUserIds() {
			when(service.findInactiveUserIds()).thenThrow(new RuntimeException());

			assertThatNoException().isThrownBy(scheduler::deleteUsers);
		}

		@Test
			void shouldCatchExistsCommandWithUserIds() {
			when(service.findInactiveUserIds()).thenReturn(Stream.of("userId"));
			when(commandService.existsCommandWithUserId(anyString())).thenThrow(new RuntimeException());

			assertThatNoException().isThrownBy(scheduler::deleteUsers);
		}

		@Test
		void shouldCatchDeleteInactiveUsers() {
			when(service.findInactiveUserIds()).thenReturn(Stream.of("userId"));
			doThrow(new RuntimeException()).when(service).deleteInactiveUser(anyString());

			assertThatNoException().isThrownBy(scheduler::deleteUsers);
		}

	}
}