/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.vorgang.common.grpc;

import static de.ozgcloud.vorgang.common.grpc.FormDataMappingUtils.*;

import java.util.Map;

import de.ozgcloud.vorgang.vorgang.GrpcFormField;
import de.ozgcloud.vorgang.vorgang.GrpcSubForm;

public class GrpcSubFormTestFactory {

	public static final String TITLE = "kontakt";
	public static final String LABEL = "Alternative kontakt Label";

	public static final String FIELD_NAME = "vorname";
	public static final String FIELD_VALUE = "Thea";
	public static final String FIELD_LABEL = "Alternative name Label";
	public static final Map<String, Object> FIELD = Map.of(LABEL_KEY, FIELD_LABEL, VALUE_KEY, FIELD_VALUE);

	public static final String SUBFORM_TITLE = "otherData";
	public static final String SUBFORM_LABEL = "Alternative otherData label";

	public static final String SUBFORM_FIELD_NAME = "E-Mail";
	public static final String SUBFORM_FIELD_VALUE = "thea@mailinator.de";
	public static final String SUBFORM_FIELD_LABEL = "Alternative E-mail label";
	public static final Map<String, Object> SUBFORM_FIELD = Map.of(VALUE_KEY, SUBFORM_FIELD_VALUE, LABEL_KEY, SUBFORM_FIELD_LABEL);

	public static final Map<String, Object> SUBFORM = Map.of(VALUE_KEY, Map.of(SUBFORM_FIELD_NAME, SUBFORM_FIELD), LABEL_KEY, SUBFORM_LABEL);

	public static GrpcSubForm create() {
		return createBuilder().build();
	}

	public static GrpcSubForm.Builder createBuilder() {
		return GrpcSubForm.newBuilder()
				.setTitle(TITLE).setLabel(LABEL)
				.addField(GrpcFormField.newBuilder().setName(FIELD_NAME).setValue(FIELD_VALUE).setLabel(FIELD_LABEL).build())
				.addSubForm(GrpcSubForm.newBuilder().setTitle(SUBFORM_TITLE).setLabel(SUBFORM_LABEL)
						.addField(GrpcFormField.newBuilder()
								.setName(SUBFORM_FIELD_NAME)
								.setLabel(SUBFORM_FIELD_LABEL)
								.setValue(SUBFORM_FIELD_VALUE)
								.build()));
	}

	public static GrpcSubForm createWithLabels() {
		return createWithLabelsBuilder().build();
	}

	public static GrpcSubForm.Builder createWithLabelsBuilder() {
		return GrpcSubForm.newBuilder()
				.setTitle(TITLE)
				.addField(GrpcFormField.newBuilder().setName(FIELD_NAME).setValue(FIELD_VALUE).setLabel(FIELD_LABEL))
				.addSubForm(GrpcSubForm.newBuilder().setTitle(SUBFORM_TITLE).setLabel(SUBFORM_LABEL)
						.addField(GrpcFormField.newBuilder()
								.setName(SUBFORM_FIELD_NAME)
								.setValue(SUBFORM_FIELD_VALUE)
								.setLabel(SUBFORM_FIELD_LABEL)
								.build()))
				.setLabel(LABEL);
	}
}